<?php
/**
 * Array access management classes.
 * Basics to provide another way to access to arrays.
 *
 * @author      Murat Purc <murat@purc.de>
 * @copyright    Murat Purc 2008
 * @date        07.10.2008
 * @package     Development
 * @subpackage  Array_Management
 */


/**
 * mpArrayManager exception, extends Exception
 *
 * @author      Murat Purc <murat@purc.de>
 * @package     Development
 * @subpackage  Array_Management
 */
class mpArrayManager_Exception extends Exception {}


/**
 * Interface for array manager
 *
 * @author      Murat Purc <murat@purc.de>
 * @package     Development
 * @subpackage  Array_Management
 * @todo        Comment code
 */
interface mpIArrayManager {

    public function exists($path);

    public function get($path, $default=null);

    public function set($path, $value);

}


/**
 * Abstract array manager class.
 *
 * Provides access to multidimensional arrays up to deepness of 4 levels.
 *
 * @author      Murat Purc <murat@purc.de>
 * @package     Development
 * @subpackage  Array_Management
 * @todo        Comment code
 */
abstract class mpArrayManager implements mpIArrayManager {

    protected $_aData;

    protected $_delem = '/';

    protected static $_instance;


    public function exists($path) {
        $a = $this->_getSections($path);

        $count = count($a);

        if ($count == 1 && is_array($this->_aData) && isset($this->_aData[$a[0]])) {
            // 1. level
            return true;
        } elseif ($count == 2 && is_array($this->_aData[$a[0]]) && isset($this->_aData[$a[0]][$a[1]])) {
            // 2. level
            return true;
        } elseif ($count == 3 && is_array($this->_aData[$a[0]][$a[1]]) && isset($this->_aData[$a[0]][$a[1]][$a[2]])) {
            // 3. level
            return true;
        } elseif ($count == 4 && is_array($this->_aData[$a[0]][$a[1]][$a[2]]) && isset($this->_aData[$a[0]][$a[1]][$a[2]][$a[3]])) {
            // 4. level
            return true;
        }

        return false;
    }


    public function get($path, $default=null) {
        $a = $this->_getSections($path);

        $count = count($a);

        if ($count == 1 && is_array($this->_aData) && isset($this->_aData[$a[0]])) {
            // 1. level
            return $this->_aData[$a[0]];
        } elseif ($count == 2 && is_array($this->_aData[$a[0]]) && isset($this->_aData[$a[0]][$a[1]])) {
            // 2. level
            return $this->_aData[$a[0]][$a[1]];
        } elseif ($count == 3 && is_array($this->_aData[$a[0]][$a[1]]) && isset($this->_aData[$a[0]][$a[1]][$a[2]])) {
            // 3. level
            return $this->_aData[$a[0]][$a[1]][$a[2]];
        } elseif ($count == 4 && is_array($this->_aData[$a[0]][$a[1]][$a[2]]) && isset($this->_aData[$a[0]][$a[1]][$a[2]][$a[3]])) {
            // 4. level
            return $this->_aData[$a[0]][$a[1]][$a[2]][$a[3]];
        }

        // return default value
        return $default;
    }


    public function set($path, $value) {
        $a = $this->_getSections($path);

        // pre check of section depth
        $count = count($a);

        if ($count > 1 && !isset($this->_aData[$a[0]])) {
            $this->_aData[$a[0]] = array();
        }

        if ($count > 2 && !isset($this->_aData[$a[0]][$a[1]])) {
            $this->_aData[$a[0]][$a[1]] = array();
        }

        if ($count > 3 && !isset($this->_aData[$a[0]][$a[1]][$a[2]])) {
            $this->_aData[$a[0]][$a[1]][$a[2]] = array();
        }

        if ($count == 1) {
            // set at 1. level
            $this->_aData[$a[0]] = $value;
        } elseif ($count == 2) {
            // set at 2. level
            $this->_aData[$a[0]][$a[1]] = $value;
        } elseif ($count == 3) {
            // set at 3. level
            $this->_aData[$a[0]][$a[1]][$a[2]] = $value;
        } else {
            // set at 4. level
            $this->_aData[$a[0]][$a[1]][$a[2]][$a[3]] = $value;
        }
    }


    private function _getSections($path) {
        $aSections = explode($this->_delem, $path);
        if (count($aSections) == 0) {
            throw new mpArrayManager_Exception('Invalid section path.');
        } elseif (count($aSections) > 4) {
            throw new mpArrayManager_Exception('Maximum provided section depth (4) is overrun.');
        }
        foreach ($aSections as $pos => $value) {
            if ((string) $value === '') {
                throw new mpArrayManager_Exception('Configuration section must be a non-empty string.');
            }
        }
        return $aSections;
    }

}